# TTTLetter class
"""Implements the functionality of a letter in Boggle."""

from graphics import *
from board import Board

class TTTCube:
    """A TTT Cube has several attributes that define it:
           *  _letter:  denotes the letter 'X', 'O', or '-' on the face of a TTT Cube
           *  _row, _col:  denotes the position on the grid this cube is placed
    """

    __slots__ = ['_letter', '_row', '_col']

    def __init__(self, row=-1, col=-1, letter=""):

        # set row, column and letter attributes
        self._row = row
        self._col = col
        self._letter = letter

    def get_row(self):
        return self._row
    
    def get_col(self):
        return self._col
    
    def get_letter(self):
        return self._letter

    def set_letter(self, char):
        if char in ["X","O","","-"]:
            self._letter = char

    def place_cube(self, board, fill_color="white"):
        '''Updates the grid cell on Board to display TTTCube'''
        row, col, let = self.get_row(), self.get_col(), self.get_letter()
        board.set_grid_cell(row, col, let,  "black", fill_color)

    def __str__(self):
        l, row, col = self.get_letter(), self._row, self._col
        return "{} at Board position ({}, {})".format(l, row, col)

    def __repr__(self):
        return str(self)

if __name__ == "__main__":
    win = GraphWin("Tic Tac Toe", 400, 400)
    board = Board(win, rows=3, cols=3)

    board.draw_board()

    tttcube1 = TTTCube(1, 1, "X")
    tttcube2 = TTTCube(1, 2, "O")
 
    tttcube1.place_cube(board, "light blue")
    tttcube2.place_cube(board, "pink")

    # pause for mouse click before exiting
    point = win.getMouse()
    win.close()
